@@ -60,7 +60,7 @@ def get_to_pe(run_id, gain_model, n_pmts):
             to_pe = np.ones(n_pmts, dtype=np.float32) * model_conf
         except np.core._exceptions.UFuncTypeError as e:
             raise (str(e) +
-                   f'\nTried multiplying by {model_conf}. Insert a number instead.')
+                   f"\nTried multiplying by {model_conf}. Insert a number instead.")
     else:
         raise NotImplementedError(f"Gain model type {model_type} not implemented")
 
@@ -83,32 +83,38 @@ FIXED_TO_PE = {
 
 
 @export
-def get_elife(run_id, elife_conf):
-    if isinstance(elife_conf, tuple) and len(elife_conf) == 3:
-        # We want to use corrections management
-        is_nt = elife_conf[-1]
-        cmt = straxen.CorrectionsManagementServices(is_nt=is_nt)
+def get_correction_from_cmt(run_id, conf):
+    if isinstance(conf, str) and conf.startswith('https://raw'):
+        # Legacy support for pax files
+        return conf
+    if isinstance(conf, tuple) and len(conf) == 3:
+        is_nt = conf[-1]
 
-        e = cmt.get_corrections_config(run_id, elife_conf[:2])
-
-    elif isinstance(elife_conf, str):
-        warn("get_elife will be replaced by CorrectionsManagementSevices",
-             DeprecationWarning, 2)
-        # Let's remove these functions and only rely on the CMT in the future
-        x = straxen.get_resource(elife_conf, fmt='npy')
-        run_index = np.where(x['run_id'] == int(run_id))[0]
-        if not len(run_index):
-            # Electron lifetime not known: using placeholders
-            e = 623e3
+        model_type, global_version = conf[:2]
+        correction = global_version  # in case is a single value
+        if 'constant' in model_type:
+            if not isinstance(global_version, (float, int)):
+                raise ValueError(f"User specify a model type {model_type} "
+                                 "and should provide a number. Got: "
+                                 f"{type(global_version)}")
         else:
-            e = x[run_index[0]]['e_life']
+            cmt = straxen.CorrectionsManagementServices(is_nt=is_nt)
+            correction = cmt.get_corrections_config(run_id, conf[:2])
+            if correction.size == 0:
+                raise ValueError(f"Could not find a value for {model_type} "
+                                 "please check it is implemented in CMT. "
+                                 f"for nT = {is_nt}")
+
+        if 'samples' in model_type:
+            return int(correction)
+        else:
+            return float(correction)
+
     else:
-        raise ValueError(
-            'Wrong elife model. Either specify a string (url) or the '
-            'Corrections Management Tools format: '
-            '(model_type->str, model_config->str, is_nT->bool)'
-            '')
-    return float(e)
+        raise ValueError("Wrong configuration. "
+                         "Please use the following format: "
+                         "(model_type->str, model_config->str or number, is_nT->bool) "
+                         f"User specify {conf} please modify")
 
 
 @export
@@ -117,11 +123,11 @@ def get_config_from_cmt(run_id, conf):
         # Legacy support for pax files
         return conf
     if not isinstance(conf, tuple):
-        raise ValueError(f'conf must be a tuple')
+        raise ValueError("conf must be a tuple")
     if not len(conf) == 3:
-        raise ValueError(f'conf must have three elements: '
-                         f'the model type, its specific configuration '
-                         f'and detector (True = nT)')
+        raise ValueError("conf must have three elements: "
+                         "the model type, its specific configuration "
+                         "and detector (True = nT)")
     model_type, model_conf, is_nt = conf
     if model_type == 'CMT_model':
         cmt = straxen.CorrectionsManagementServices(is_nt=is_nt)
@@ -129,7 +135,20 @@ def get_config_from_cmt(run_id, conf):
         this_file = ' '.join(map(str, this_file))
 
     else:
-        raise ValueError(f'Wrong NN configuration, please look at this {nn_config} '
-                         'and modify it accordingly')
+        raise ValueError(f"Wrong NN configuration, please look at this {conf} "
+                         "and modify it accordingly")
 
     return this_file
+
+
+def get_elife(run_id, elife_conf):
+    # 1T support for electron lifetimes from a file
+    # Let's remove these functions and only rely on the CMT in the future
+    x = straxen.get_resource(elife_conf, fmt='npy')
+    run_index = np.where(x['run_id'] == int(run_id))[0]
+    if not len(run_index):
+        # Electron lifetime not known: using placeholders
+        e = 623e3
+    else:
+        e = x[run_index[0]]['e_life']
+    return float(e)
